SECTOR_BM_DEFAULT = {
     'AUTOMOBILE': 'NIFTY AUTO',
     'CEMENT & CEMENT PRODUCTS': 'NIFTY INFRA',
     'CHEMICALS': 'NIFTY COMMODITIES',
     'CONSTRUCTION': 'NIFTY REALTY',
     'CONSUMER GOODS': 'NIFTY FMCG',
     'CONSUMER SERVICES': 'NIFTY CONSUMPTION',
     'FERTILISERS & PESTICIDES': 'NIFTY COMMODITIES',
     'FINANCIAL SERVICES': 'NIFTY FIN SERVICE',
     'HEALTHCARE SERVICES': 'NIFTY HEALTHCARE INDEX',
     'INDUSTRIAL MANUFACTURING': 'NIFTY INFRA',
     'IT': 'NIFTY IT',
     'MEDIA ENTERTAINMENT & PUBLICATION': 'NIFTY MEDIA',
     'METALS': 'NIFTY METAL',
     'OIL & GAS': 'NIFTY OIL & GAS',
     'PAPER AND JUTE': 'NIFTY COMMODITIES',
     'PHARMA': 'NIFTY PHARMA',
     'POWER': 'NIFTY ENERGY',
     'SERVICES': 'NIFTY SERV SECTOR',
     'TELECOM': 'NIFTY INFRA',
     'TEXTILES': 'NIFTY CONSUMPTION',
     'UTILITIES': 'NIFTY CONSUMPTION'
}

INDICES = list(set(SECTOR_BM_DEFAULT.values())) + [
    'NIFTY 50', 
    'NIFTY 100', 
    'NIFTY MIDCAP 100', 
    'NIFTY SMLCAP 100',
    'NIFTY CONSUMER DURABLES',
    'NIFTY BANK',
    'NIFTY PVT BANK',
    'NIFTY PSU BANK',
    'NIFTY100 ENHANCED ESG'
]

SAA_ASSET_ALLOCATION = 'SAA Asset Allocation'
ASSET_ALLOCATION = 'Asset Allocation'
BENCHMARK_ALLOCATION = 'Benchmark Allocation'
SAA_BENCHMARK_ALLOCATION = 'SAA Benchmark Allocation'
